summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/spinbox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kalarm/lib/spinbox.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/spinbox.h')
-rw-r--r--kalarm/lib/spinbox.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kalarm/lib/spinbox.h b/kalarm/lib/spinbox.h
index cf74e9deb..4b269d6a5 100644
--- a/kalarm/lib/spinbox.h
+++ b/kalarm/lib/spinbox.h
@@ -39,23 +39,24 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class SpinBox : public QSpinBox
+class SpinBox : public TQSpinBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit SpinBox(TQWidget* parent = 0, const char* name = 0);
+ explicit SpinBox(TQWidget* tqparent = 0, const char* name = 0);
/** Constructor.
* @param minValue The minimum value which the spin box can have.
* @param maxValue The maximum value which the spin box can have.
* @param step The (unshifted) step interval.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- SpinBox(int minValue, int maxValue, int step = 1, TQWidget* parent = 0, const char* name = 0);
+ SpinBox(int minValue, int maxValue, int step = 1, TQWidget* tqparent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the spin box can be changed by the user.
@@ -39,23 +39,24 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -39,23 +39,24 @@
* @param maxValue The maximum value which the spin box can have.
* @param step The (unshifted) step interval.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/